@@ -89,22 +89,34 @@ LEFT OUTER JOIN (
 	(phorizon INNER JOIN phtexture ON phorizon.phiid = phtexture.phiidref) 
 	LEFT OUTER JOIN phtexturemod ON phtexture.phtiid = phtexturemod.phtiidref) 
 	LEFT OUTER JOIN (SELECT * FROM metadata_domain_detail WHERE metadata_domain_detail.domain_id = 190) AS tmod ON phtexturemod.texmod =   tmod.choice_id;"
+
 	
-	## TODO: does this query need a DISTINCT keyword ?
 	# get geomorphic features
-	q.geomorph <- "SELECT pedon.peiid, sitegeomordesc.geomfeatid, sitegeomordesc.existsonfeat, 	sitegeomordesc.geomfmod, geomorfeat.geomfname, IIf(([sitegeomordesc].[geomftiidref]=1),'landform',IIf(([sitegeomordesc].[geomftiidref]=2),'landscape',IIf(([sitegeomordesc].[geomftiidref]=3),'microfeature','anthropogenic feature'))) AS feature_type
-FROM (geomorfeat INNER JOIN (site INNER JOIN sitegeomordesc ON site.siteiid = sitegeomordesc.siteiidref) ON (geomorfeat.geomftdbsidref = sitegeomordesc.geomftdbsidref) AND (geomorfeat.geomftiidref = sitegeomordesc.geomftiidref) AND (geomorfeat.geomfiid = sitegeomordesc.geomfiidref)) INNER JOIN pedon ON site.siteiid = pedon.siteiidref 
+	##changes made: added join to peiid through the siteobs table, change to key field linkages for geomftiidref - key field was dropped from sitegeomordesc table
+	## TODO: does this query need a DISTINCT keyword ?
+	q.geomorph <- "SELECT pedon.peiid, sitegeomordesc.geomfeatid, sitegeomordesc.existsonfeat, sitegeomordesc.geomfmod, sitegeomordesc.geomfiidref, IIf(([geomorfeat].[geomftiidref]=1),'landform',IIf(([geomorfeat].[geomftiidref]=2),'landscape',IIf(([geomorfeat].[geomftiidref]=3),'microfeature','anthropogenic feature'))) AS feature_type
+FROM geomorfeattype RIGHT JOIN (geomorfeat RIGHT JOIN ((site INNER JOIN sitegeomordesc ON site.siteiid = sitegeomordesc.siteiidref) INNER JOIN (siteobs INNER JOIN pedon ON siteobs.siteobsiid = pedon.siteobsiidref) ON site.siteiid = siteobs.siteiidref) ON geomorfeat.geomfiid = sitegeomordesc.geomfiidref) ON geomorfeattype.geomftiid = geomorfeat.geomftiidref
 ORDER BY peiid ASC;"
-  
+
+	# get petaxhistory data 
+	q.taxhistory <- "SELECT peiidref as peiid, classdate, classifier, classtype, taxonname, tk.choice_label as taxon_kind, ss.choice_label as series_status, ps.choice_label as part_size_class, ts.choice_label as tax_subgroup, te.choice_label as tax_edition, osdtypelocflag
+  	FROM (((((petaxhistory 
+		LEFT OUTER JOIN (SELECT * FROM metadata_domain_detail WHERE domain_id = 127) AS ps ON petaxhistory.taxpartsize = ps.choice_id)
+  		LEFT OUTER JOIN (SELECT * FROM metadata_domain_detail WHERE domain_id = 187) AS ts ON petaxhistory.taxsubgrp = ts.choice_id)
+  		LEFT OUTER JOIN (SELECT * FROM metadata_domain_detail WHERE domain_id = 102) AS tk ON petaxhistory.taxonkind = tk.choice_id)
+		LEFT OUTER JOIN (SELECT * FROM metadata_domain_detail WHERE domain_id = 4956) AS ss ON petaxhistory.seriesstatus = ss.choice_id)
+		LEFT OUTER JOIN (SELECT * FROM metadata_domain_detail WHERE domain_id = 2030) AS te ON petaxhistory.seriesstatus = te.choice_id)
+	ORDER BY petaxhistory.peiidref;"	
 	
 	# setup connection to our pedon database
-	channel <- odbcConnectAccess(dsn, readOnlyOptimize=TRUE)
+	channel <- odbcConnectAccess2007(dsn, readOnlyOptimize=TRUE)
 	
 	# exec queries
 	d.diagnostic <- sqlQuery(channel, q.diagnostic, stringsAsFactors=FALSE)
 	d.rf.summary <- sqlQuery(channel, q.rf.summary, stringsAsFactors=FALSE)
 	d.hz.texmod <- sqlQuery(channel, q.hz.texmod, stringsAsFactors=FALSE)
 	d.geomorph <- sqlQuery(channel, q.geomorph, stringsAsFactors=FALSE)
+	d.taxhistory <- sqlQuery(channel, q.taxhistory, stringsAsFactors=FALSE)
 	
 	# close connection
 	odbcClose(channel)
@@ -113,5 +125,5 @@ ORDER BY peiid ASC;"
 	d.diag.boolean <- diagHzLongtoWide(d.diagnostic)
 	
 	# return a list of results
-	return(list(diagnostic=d.diagnostic, diagHzBoolean=d.diag.boolean, frag_summary=d.rf.summary, texmodifier=d.hz.texmod, geomorph=d.geomorph))
+	return(list(diagnostic=d.diagnostic, diagHzBoolean=d.diag.boolean, frag_summary=d.rf.summary, texmodifier=d.hz.texmod, geomorph=d.geomorph, taxhistory=d.taxhistory))
 }
